@@ -21,6 +21,7 @@ from langtrace_python_sdk.utils.llm import (
     get_llm_request_attributes,
     get_extra_attributes,
     get_llm_url,
+    get_span_name,
     set_event_completion,
     set_usage_attributes,
 )
@@ -56,7 +57,9 @@ def rerank(original_method, version, tracer):
 
         attributes = LLMSpanAttributes(**span_attributes)
 
-        span = tracer.start_span(APIS["RERANK"]["METHOD"], kind=SpanKind.CLIENT)
+        span = tracer.start_span(
+            name=get_span_name(APIS["RERANK"]["METHOD"]), kind=SpanKind.CLIENT
+        )
         for field, value in attributes.model_dump(by_alias=True).items():
             set_span_attribute(span, field, value)
         try:
@@ -136,7 +139,10 @@ def embed(original_method, version, tracer):
 
         attributes = LLMSpanAttributes(**span_attributes)
 
-        span = tracer.start_span(APIS["EMBED"]["METHOD"], kind=SpanKind.CLIENT)
+        span = tracer.start_span(
+            name=get_span_name(APIS["EMBED"]["METHOD"]),
+            kind=SpanKind.CLIENT,
+        )
         for field, value in attributes.model_dump(by_alias=True).items():
             set_span_attribute(span, field, value)
         try:
@@ -224,7 +230,9 @@ def chat_create(original_method, version, tracer):
             # stringify the list of objects
             attributes.llm_tool_results = json.dumps(kwargs.get("tool_results"))
 
-        span = tracer.start_span(APIS["CHAT_CREATE"]["METHOD"], kind=SpanKind.CLIENT)
+        span = tracer.start_span(
+            name=get_span_name(APIS["CHAT_CREATE"]["METHOD"]), kind=SpanKind.CLIENT
+        )
 
         # Set the attributes on the span
         for field, value in attributes.model_dump(by_alias=True).items():
@@ -390,24 +398,16 @@ def chat_stream(original_method, version, tracer):
             # stringify the list of objects
             attributes.llm_tool_results = json.dumps(kwargs.get("tool_results"))
 
-        span = tracer.start_span(APIS["CHAT_STREAM"]["METHOD"], kind=SpanKind.CLIENT)
+        span = tracer.start_span(
+            name=get_span_name(APIS["CHAT_STREAM"]["METHOD"]), kind=SpanKind.CLIENT
+        )
         for field, value in attributes.model_dump(by_alias=True).items():
             set_span_attribute(span, field, value)
         try:
             # Attempt to call the original method
             result = wrapped(*args, **kwargs)
-            span.add_event(Event.STREAM_START.value)
             try:
                 for event in result:
-                    if hasattr(event, "text") and event.text is not None:
-                        content = event.text
-                    else:
-                        content = ""
-                    span.add_event(
-                        Event.STREAM_OUTPUT.value,
-                        {SpanAttributes.LLM_CONTENT_COMPLETION_CHUNK: "".join(content)},
-                    )
-
                     if (
                         hasattr(event, "finish_reason")
                         and event.finish_reason == "COMPLETE"
@@ -488,15 +488,14 @@ def chat_stream(original_method, version, tracer):
                                         (usage.input_tokens or 0)
                                         + (usage.output_tokens or 0),
                                     )
-
-                                    span.set_attribute(
-                                        "search_units",
-                                        usage.search_units or 0,
-                                    )
+                                    if usage.search_units is not None:
+                                        span.set_attribute(
+                                            "search_units",
+                                            usage.search_units or 0,
+                                        )
 
                     yield event
             finally:
-                span.add_event(Event.STREAM_END.value)
                 span.set_status(StatusCode.OK)
                 span.end()
 
